@@ -2,13 +2,13 @@ package shell
 
 import (
 	"io"
-	"os"
 	"path/filepath"
 
-	"github.com/pkg/errors"
+	"github.com/cashapp/hermit/errors"
+	"github.com/cashapp/hermit/internal/system"
 )
 
-const zshShellHooks = commonHooks + `
+var zshShellHooks = `
 precmd_functions+=(change_hermit_env)
 
 # shellcheck disable=SC2154
@@ -35,7 +35,7 @@ func (sh *Zsh) ActivationScript(w io.Writer, config ActivationConfig) error { //
 }
 
 func (sh *Zsh) ActivationHooksInstallation() (path, script string, err error) { // nolint: golint
-	home, err := os.UserHomeDir()
+	home, err := system.UserHomeDir()
 	if err != nil {
 		return "", "", errors.WithStack(err)
 	}
@@ -44,5 +44,5 @@ func (sh *Zsh) ActivationHooksInstallation() (path, script string, err error) {
 }
 
 func (sh *Zsh) ActivationHooksCode() (script string, err error) { // nolint: golint
-	return zshShellHooks, err
+	return commonHooks + zshShellHooks, nil
 }
